@@ -222,6 +222,10 @@ $(function() {
 			tabSize: 4,
 			indentUnit: 4,
 			indentWithTabs: true,
+			highlightSelectionMatches: true,
+			styleSelectedText: true,
+			autoCloseBrackets: true,
+			styleActiveLine: true,
 			extraKeys: {
 				"F1": function(cm) {
 					displayHelp(cm);
@@ -249,13 +253,6 @@ $(function() {
 
 		// Hook up with cursor activity event
 		editor.on("cursorActivity", function(cm) {
-				// Highlight active line
-				cm.removeLineClass(hlLine, "background", "activeline");
-				hlLine = cm.addLineClass(cm.getCursor().line, "background", "activeline");
-
-				// Highlight selection matches
-				cm.matchHighlight("CodeMirror-matchhighlight");
-
 				// Show editor statistics
 				window.showEditorStats(cm);
 		});
@@ -329,9 +326,6 @@ $(function() {
 
 		}, 0);
 
-		// Highlight active line
-		var hlLine = editor.addLineClass(0, "background", "activeline");
-		
 		tabId++;
 	};
 	
@@ -782,4 +776,8 @@ $(function() {
 		});
 	});
 
-});
\ No newline at end of file
+	$(".navbar .brand").click(function() {
+		$(document).trigger("action-about");
+	});
+
+});
